==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/editacecontroller.php <==
<?php
/**
 * stanislav.elbl, 24.11.2015
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MVC\HttpController;
use Ron\MVC\JsonOutputObject;
use Ron\TextManager;
use RonPortal\Controls\RozdeleniShiftForm;
use RonPortal\Dokumenty\DokumentOutputObject;
use RonPortal\Dokumenty\DokumentUploadOutput;
use RonPortal\Dokumenty\DokumentyUtils;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalSettings;
use RonPortal\System\FotoOutputObject;
use RonPortal\User;

class EditaceController extends HttpController
{
    /** @var Database */
    var $database;

    /**
     * EditaceController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param int $idpp
     * @param int $obdobi
     * @return bool
     */
    function jePravoNaDokumentDochazky($idpp, $obdobi)
    {
        Prava::nastavObdobiProPrava($obdobi, DateUtils::lastDayOfMonth($obdobi));

        Prava::nactiPravaUzivatele($this ->database, User::getRC());

        $prava = Prava::vratPrava('prohlizeni');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        $prava = Prava::vratPrava('editace');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        $prava = Prava::vratPrava('editacedokument');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        return false;
    }


    function download()
    {
        $idPP = (int)$_GET['idpp'];
        $obdobi = DateUtils::urlStringToDate($_GET['obdobi'], true);
        $idDokumentu = (int)$_GET['record'];

        if (!$this ->jePravoNaDokumentDochazky($idPP, $obdobi)) {
            throw new NeniPravoException();
        }

        $params = $this ->database ->createParameters();
        $sql =
            'SELECT DokumentDochazky.Id ' .
            ' FROM DokumentDochazky, PracovniPomer ' .
            ' WHERE DokumentDochazky.Id = ' . $params ->addParameter((int)$idDokumentu) .
            "   AND DokumentDochazky.Aplikace = 'ADS' " .
            '   AND DokumentDochazky.PocatekObdobi = ' . $params ->addParameter($this ->database ->dateToParam($obdobi)) .
            '   AND DokumentDochazky.RC = PracovniPomer.RC ' .
            '   AND DokumentDochazky.OsobniCislo = PracovniPomer.OsobniCislo ' .
            '   AND DokumentDochazky.DatumNastupu = PracovniPomer.DatumNastupu ' .
            '   AND PracovniPomer.Id = ' . $params ->addParameter((int)$idPP);


        $cursor = $this ->database ->getSqlResult($sql, $params);
        if (!$row = $cursor ->fetch()) {
            throw new \Exception('Zadany dokument nebyl nalezen! Document not found!');
        }

        return new DokumentOutputObject($this ->database, $idDokumentu);
    }


    function dokumentUpload()
    {
        $result = new DokumentUploadOutput();

        try {
            $idPP = (int)$_GET['idpp'];
            $obdobi = DateUtils::urlStringToDate($_GET['obdobi']);

            if (!$idPP) {
                throw new \Exception('Chyba pri kontrole prav! Neni zadan pracovni pomer!');
            }

            $pp = PracovniPomer::nactiPP($this ->database, $idPP);

            Prava::nactiPravaUzivatele($this ->database, User::getRC());
            Prava::nastavObdobiProPrava($obdobi, DateUtils::lastDayOfMonth($obdobi));

            $prava = Prava::vratPrava('editacedokument');
            if (!$prava ->lzeZobrazitPP($idPP)) {
                throw new NeniPravoException();
            }

            $den = null;
            if (isset($_POST['Dokument_Den'])  &&  $_POST['Dokument_Den'] != '') {
                $den = DateUtils::dateStringToTimestamp($_POST['Dokument_Den']);
            }

            $idDokumentu = DokumentyUtils::vlozDokument($this ->database, 'soubor', $_POST['typ'], $_POST['popis'], $this);

            // vlozi zaznam do vazebni tabulky
            $rec = new RonPortalDBRecord($this ->database, 'DokumentDochazky', $this);

            $rec ->addField('Id', 'int', false, 0, $idDokumentu);
            $rec ->addField('PocatekObdobi', 'date', false, 0, $obdobi);
            $rec ->addField('Aplikace', '', false, 10, 'ADS');
            $rec ->addField('RC', '', false, 30, $pp ->rc);
            $rec ->addField('OsobniCislo', '', false, 30, $pp ->osobniCislo);
            $rec ->addField('DatumNastupu', 'date', false, 0, $pp ->datumNastupu);

            if ($den) {
                $rec ->addField('Den', 'date', false, 0, $den);
            }

            $rec ->insertRecord();
        } catch (\Exception $e) {
            $result ->setError($e ->getMessage());
        }

        return $result;
    }


    /**
     * Obslouzi vyber rozdeleni osoby (shiftform)
     * @return JsonOutputObject
     */
    public function rozdeleniOsoby()
    {
        $result = new JsonOutputObject();

        try {
            if ( !RonPortalSettings::getPouzivatRozdeleniDV()  ||  !RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)  ||  !RonPortalSettings::getIntValue(RonPortalSettings::DV_TYP_ROZDELENI)) {
                throw new \Exception('Chyba! Tato funkce neni povolena!');
            }

            Prava::nastavObdobiProPrava(time(), time());

            if (!Prava::vratPrava('editace') ->lzeZobrazitPP($_GET['idpp'])) {
                if (!Prava::vratPrava('editace_r') ->lzeZobrazitPP($_GET['idpp'])) {
                    throw new NeniPravoException();
                }
            }

            $shiftForm = new RozdeleniShiftForm($this ->database, RonPortalSettings::getIntValue(RonPortalSettings::DV_TYP_ROZDELENI), [Prava::vratPrava('editace'), Prava::vratPrava('editace_r')]);
            $data = $shiftForm ->handleAction();

            $result ->addData('data', $data);
            $result ->compress = 'gzip';


        } catch (\Exception $e) {
            $result ->addError($e ->getMessage());
        }

        return $result;
    }


    function foto()
    {
        $idpp = (int)$_GET['idpp'];

        Prava::nastavObdobiProPrava(time(), time());
        Prava::nactiPravaUzivatele($this ->database, User::getRC());

        if (!Prava::lzeZobrazitPP( [
            Prava::vratPrava('prohlizeni'),
            Prava::vratPrava('editace') ], $idpp )
        ) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($_GET['idpp']);
        return $result;
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');

        switch ($_GET['action']) {
            case 'translations' :
                return $this ->translations();

            case 'download' :
                return $this ->download();

            case 'dokumentupload' :
                return $this ->dokumentUpload();

            case 'rozdeleniosoby' :
                return $this ->rozdeleniOsoby();

            case 'foto' :
                return $this ->foto();
        }

        throw new \Exception('Chyba v EditaceController::handleAction - neznama akce: ' . $action);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/editace/editacecontroller.php <==
<?php
/**
 * stanislav.elbl, 24.11.2015
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\Csrf;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RozdeleniShiftForm;
use RonPortal\Dokumenty\DokumentOutputObject;
use RonPortal\Dokumenty\DokumentUploadOutput;
use RonPortal\Dokumenty\DokumentyUtils;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalSettings;
use RonPortal\System\FotoOutputObject;
use RonPortal\User;

class EditaceController extends JsonController
{
    /** @var Database */
    var $database;

    /**
     * EditaceController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param int $idpp
     * @param int $obdobi
     * @return bool
     */
    function jePravoNaDokumentDochazky($idpp, $obdobi)
    {
        Prava::nastavObdobiProPrava($obdobi, DateUtils::lastDayOfMonth($obdobi));

        Prava::nactiPravaUzivatele($this ->database, User::getRC());

        $prava = Prava::vratPrava('prohlizeni');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        $prava = Prava::vratPrava('editace');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        $prava = Prava::vratPrava('editacedokument');
        if ($prava  &&  $prava->lzeZobrazitPP($idpp)) {
            return true;
        }

        return false;
    }


    function download()
    {
        $idPP = (int)$_GET['idpp'];
        $obdobi = DateUtils::urlStringToDate($_GET['obdobi'], true);
        $idDokumentu = (int)$_GET['record'];

        if (!$this ->jePravoNaDokumentDochazky($idPP, $obdobi)) {
            throw new NeniPravoException();
        }

        $params = $this ->database ->createParameters();
        $sql =
            'SELECT DokumentDochazky.Id ' .
            ' FROM DokumentDochazky, PracovniPomer ' .
            ' WHERE DokumentDochazky.Id = ' . $params ->addParameter((int)$idDokumentu) .
            "   AND DokumentDochazky.Aplikace = 'ADS' " .
            '   AND DokumentDochazky.PocatekObdobi = ' . $params ->addParameter($this ->database ->dateToParam($obdobi)) .
            '   AND DokumentDochazky.RC = PracovniPomer.RC ' .
            '   AND DokumentDochazky.OsobniCislo = PracovniPomer.OsobniCislo ' .
            '   AND DokumentDochazky.DatumNastupu = PracovniPomer.DatumNastupu ' .
            '   AND PracovniPomer.Id = ' . $params ->addParameter((int)$idPP);


        $cursor = $this ->database ->getSqlResult($sql, $params);
        if (!$row = $cursor ->fetch()) {
            throw new \Exception('Zadany dokument nebyl nalezen! Document not found!');
        }

        return new DokumentOutputObject($this ->database, $idDokumentu);
    }


    /**
     * @param JsonOutputObject $output
     * @throws NeniPravoException
     * @throws \Exception
     * @throws \Ron\RonException
     */
    function dokumentUpload($output)
    {
//        $result = new DokumentUploadOutput();
//
//        try {
            $idPP = (int)$_GET['idpp'];
            $obdobi = DateUtils::urlStringToDate($_GET['obdobi']);

            if (!$idPP) {
                throw new \Exception('Neni zadan pracovni pomer!');
            }

            $pp = PracovniPomer::nactiPP($this ->database, $idPP);

            Prava::nactiPravaUzivatele($this ->database, User::getRC());
            Prava::nastavObdobiProPrava($obdobi, DateUtils::lastDayOfMonth($obdobi));

            $prava = Prava::vratPrava('editacedokument');
            if (!$prava ->lzeZobrazitPP($idPP)) {
                throw new NeniPravoException();
            }

            Csrf::validateCSRFPostParam();

            $den = null;
            if (isset($_POST['Dokument_Den'])  &&  $_POST['Dokument_Den'] != '') {
                $den = DateUtils::dateStringToTimestamp($_POST['Dokument_Den']);
            }

            //$idDokumentu = DokumentyUtils::vlozDokument($this ->database, 'soubor', $_POST['typ'], $_POST['popis'], $this);
            $idDokumentu = DokumentyUtils::vlozDokumentJson($this ->database, 'soubor', $_POST['typ'], $_POST['popis'], $output, $this);

            // vlozi zaznam do vazebni tabulky
            $rec = new RonPortalDBRecord($this ->database, 'DokumentDochazky', $this);

            $rec ->addIntField('Id', false, $idDokumentu);
            $rec ->addDateField('PocatekObdobi', false, $obdobi);
            $rec ->addStringField('Aplikace', false, 10, 'ADS');
            $rec ->addStringField('RC', false, 30, $pp ->rc);
            $rec ->addStringField('OsobniCislo', false, 30, $pp ->osobniCislo);
            $rec ->addDateField('DatumNastupu', false, $pp ->datumNastupu);

            if ($den) {
                $rec ->addDateField('Den', false, $den);
                $output ->addText('den', StringUtils::format('date', $den));

                $output ->addText('downloadUrl',
                    '?menuid=editace&action=download&idpp=' . $idPP . '&obdobi=' . DateUtils::dateToUrlString($obdobi) . '&record=' . $rec['Id'] );
            }

            $rec ->insertRecord();
//        } catch (\Exception $e) {
//            $result ->setError($e ->getMessage());
//        }
//        return $result;
    }


    /**
     * Obslouzi vyber rozdeleni osoby (shiftform)
     * @param JsonOutputObject $output
     * @throws NeniPravoException
     * @throws \Exception
     */
    public function rozdeleniOsoby($output)
    {
        if ( !RonPortalSettings::getPouzivatRozdeleniDV()  ||  !RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)  ||  !RonPortalSettings::getIntValue(RonPortalSettings::DV_TYP_ROZDELENI)) {
            throw new \Exception('Chyba! Tato funkce neni povolena!');
        }

        Prava::nastavObdobiProPrava(time(), time());

        if (!Prava::vratPrava('editace') ->lzeZobrazitPP($_GET['idpp'])) {
            if (!Prava::vratPrava('editace_r') ->lzeZobrazitPP($_GET['idpp'])) {
                throw new NeniPravoException();
            }
        }

        $shiftForm = new RozdeleniShiftForm($this ->database, RonPortalSettings::getIntValue(RonPortalSettings::DV_TYP_ROZDELENI), [Prava::vratPrava('editace'), Prava::vratPrava('editace_r')]);
        $data = $shiftForm ->handleAction();

        $output ->addData('data', $data);
        $output ->compress = 'gzip';
    }


    function foto()
    {
        $idpp = (int)$_GET['idpp'];

        Prava::nastavObdobiProPrava(time(), time());
        Prava::nactiPravaUzivatele($this ->database, User::getRC());

        if (!Prava::lzeZobrazitPP( [
            Prava::vratPrava('prohlizeni'),
            Prava::vratPrava('editace') ], $idpp )
        ) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($_GET['idpp']);
        return $result;
    }



    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'rozdeleniosoby' :
                $this ->rozdeleniOsoby($output);
                return;

            case 'dokumentupload' :
                $this ->dokumentUpload($output);
                return;
        }

        throw new \Exception('Chyba v EditaceController::handleAction - neznama akce: ' . $action);
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');

        switch ($_GET['action']) {
            case 'translations' :
                return $this ->translations();

            case 'download' :
                return $this ->download();

            case 'foto' :
                return $this ->foto();

//            case 'dokumentupload' :
//                return $this ->dokumentUpload();
        }

        return parent::handleAction($action);
    }
}
